@@ -1,3 +1,4 @@
+import datetime
 import os
 import itertools
 import multiprocessing as mp
@@ -13,6 +14,7 @@ from .signals import *
 from .aggregate import *
 
 
+
 def multi_process(function, parameters, number_of_core=8):
     pool = mp.Pool(processes=number_of_core)
     pool.map(function, parameters)
@@ -207,7 +209,7 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
     else:
         print('Risk free rate: {:.2f} %'.format(risk_free_rate))
 
-    print('Backtest result is loading. Please wait patiently.')
+    print(datetime.datetime.now().strftime('%H:%M:%S'), 'Backtest result is loading. Please wait patiently.')
 
     manager_list = mp.Manager().list()  # To save the result with index number
 
@@ -216,11 +218,11 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
         para_combination['risk_free_rate'] = risk_free_rate
         cal_performance_list.append((para_combination, manager_list))
 
-    pool = mp.Pool(processes=number_of_core)
-    pool.map(mp_cal_performance, cal_performance_list)
-    pool.close()
-    # for c in cal_performance_list:
-    #     mp_cal_performance(c)
+    # pool = mp.Pool(processes=number_of_core)
+    # pool.map(mp_cal_performance, cal_performance_list)
+    # pool.close()
+    for performance_list in cal_performance_list:
+        mp_cal_performance(performance_list)
 
     df_backtest_result = pd.DataFrame(list(manager_list))
     df_backtest_result = df_backtest_result.sort_values(by='reference_index')
@@ -420,6 +422,7 @@ def resample_summary_to_daily(para_combination, folder=''):
 
     last_realized_capital = initial_capital
 
+
     df = (df.lazy()
           .filter((pl.col('action') != '') &
                   (pl.col('action').is_not_null()) &
@@ -433,7 +436,6 @@ def resample_summary_to_daily(para_combination, folder=''):
           .filter(pl.col('action') != 'open')
           .collect()
           )
-
     df_backtest = df.to_pandas()
 
     # Read source data
@@ -510,15 +512,7 @@ def cal_performance(para_combination):
         else:
             df_backtest = pd.read_csv(save_path, index_col=0)  # Daraframe that may not be daily
 
-        first_date_str = df_backtest.at[df_backtest.index[0],  'date']
-        if '-' in first_date_str:
-            df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
-        else:
-            try:
-                df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y%m%d')
-            except:
-                df_backtest['date'] = pd.to_datetime(df_backtest['date'])
-
+        df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
         df_backtest = df_backtest.loc[(df_backtest['date'] >= start_date) & (df_backtest['date'] <= end_date)]
         df_backtest = df_backtest.reset_index(drop=True)  # Reset Index
         df_daily = df_backtest
