@@ -1,7 +1,11 @@
+import warnings
+warnings.simplefilter("ignore", UserWarning)
+
 from dash import Dash, dcc, html, Input, Output, State, ALL
 import dash_daq as daq
 from .components import *
 import time
+import dash_dangerously_set_inner_html
 
 class Aggregate:
 
