@@ -1,3 +1,6 @@
+import warnings
+warnings.simplefilter("ignore", UserWarning)
+
 import pandas as pd
 import numpy as np
 import datetime
