@@ -1,6 +1,9 @@
+import warnings
+warnings.simplefilter("ignore", UserWarning)
+
 from dash import Dash, dcc, html, Input, Output, State, ALL
 from .components import *
-
+import dash_dangerously_set_inner_html
 import os
 
 class Plot:
