@@ -1,3 +1,6 @@
+import warnings
+warnings.simplefilter("ignore", UserWarning)
+
 from dash import Dash, dcc, html, Input, Output, State, ALL
 from .components import *
 
